diff PalanthirServer/main.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children 601ee9b7f2c7
line wrap: on
line diff
--- a/PalanthirServer/main.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/main.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -18,7 +18,7 @@
  **/
 
 
-#include "PalantirRestApi.h"
+#include "PalanthirRestApi.h"
 
 #include <stdio.h>
 
@@ -26,10 +26,10 @@
 #include "../Core/HttpServer/FilesystemHttpHandler.h"
 #include "../Core/HttpServer/MongooseServer.h"
 #include "DicomProtocol/DicomServer.h"
-#include "PalantirInitialization.h"
+#include "PalanthirInitialization.h"
 
 
-using namespace Palantir;
+using namespace Palanthir;
 
 
 class MyDicomStore : public IStoreRequestHandler
@@ -99,14 +99,14 @@
   {
     if (argc >= 2)
     {
-      PalantirInitialize(argv[1]);
+      PalanthirInitialize(argv[1]);
     }
     else
     {
-      PalantirInitialize();
+      PalanthirInitialize();
     }
 
-    std::string storageDirectory = GetGlobalStringParameter("StorageDirectory", "PalantirStorage");
+    std::string storageDirectory = GetGlobalStringParameter("StorageDirectory", "PalanthirStorage");
     ServerIndex index(storageDirectory);
     MyDicomStoreFactory storeScp(index, storageDirectory);
 
@@ -116,7 +116,7 @@
       dicomServer.SetCalledApplicationEntityTitleCheck(true);
       dicomServer.SetStoreRequestHandlerFactory(storeScp);
       dicomServer.SetPortNumber(GetGlobalIntegerParameter("DicomPort", 4242));
-      dicomServer.SetApplicationEntityTitle(GetGlobalStringParameter("DicomAet", "PALANTIR"));
+      dicomServer.SetApplicationEntityTitle(GetGlobalStringParameter("DicomAet", "PALANTHIR"));
 
       // HTTP server
       MongooseServer httpServer;
@@ -137,13 +137,13 @@
         httpServer.SetSslEnabled(false);
       }
 
-#if PALANTIR_STANDALONE == 1
-      httpServer.RegisterHandler(new EmbeddedResourceHttpHandler("/app", EmbeddedResources::PALANTIR_EXPLORER));
+#if PALANTHIR_STANDALONE == 1
+      httpServer.RegisterHandler(new EmbeddedResourceHttpHandler("/app", EmbeddedResources::PALANTHIR_EXPLORER));
 #else
-      httpServer.RegisterHandler(new FilesystemHttpHandler("/app", PALANTIR_PATH "/PalantirExplorer"));
+      httpServer.RegisterHandler(new FilesystemHttpHandler("/app", PALANTHIR_PATH "/PalanthirExplorer"));
 #endif
 
-      httpServer.RegisterHandler(new PalantirRestApi(index, storageDirectory));
+      httpServer.RegisterHandler(new PalanthirRestApi(index, storageDirectory));
 
       // GO !!!
       httpServer.Start();
@@ -158,12 +158,12 @@
 
     storeScp.Done();
   }
-  catch (PalantirException& e)
+  catch (PalanthirException& e)
   {
     std::cout << "EXCEPT [" << e.What() << "]" << std::endl;
   }
 
-  PalantirFinalize();
+  PalanthirFinalize();
 
   return 0;
 }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium